@@ -1,8 +1,8 @@
-# $Header: /usr/local/CVS/Perl-Metrics-Simple/lib/Perl/Metrics/Simple/Analysis/File.pm,v 1.8 2006/11/27 06:06:00 matisse Exp $
-# $Revision: 1.8 $
+# $Header: /usr/local/CVS/Perl-Metrics-Simple/lib/Perl/Metrics/Simple/Analysis/File.pm,v 1.10 2006/12/02 17:06:50 matisse Exp $
+# $Revision: 1.10 $
 # $Author: matisse $
 # $Source: /usr/local/CVS/Perl-Metrics-Simple/lib/Perl/Metrics/Simple/Analysis/File.pm,v $
-# $Date: 2006/11/27 06:06:00 $
+# $Date: 2006/12/02 17:06:50 $
 ###############################################################################
 
 package Perl::Metrics::Simple::Analysis::File;
@@ -16,7 +16,7 @@ use Perl::Metrics::Simple::Analysis;
 use PPI;
 use Readonly;
 
-our $VERSION = '0.022';
+our $VERSION = '0.03';
 
 Readonly::Scalar my $ALL_NEWLINES_REGEX => qr/ ( \n ) /xm;
 Readonly::Array our @LOGIC_OPERATORS    =>
@@ -62,7 +62,7 @@ sub _init {
 
     my @sub_analysis = ();
     my $sub_elements = $document->find('PPI::Statement::Sub');
-    @sub_analysis = @{ $self->_iterate_over_subs( $sub_elements, $path ) };
+    @sub_analysis = @{ $self->_iterate_over_subs( $sub_elements ) };
 
     $Main_Stats{$self} =
       $self->analyze_main( $document, $sub_elements, \@sub_analysis );
@@ -109,8 +109,10 @@ sub analyze_main {
     $document_without_subs->prune('PPI::Statement::Sub');
     my $complexity = $self->measure_complexity($document_without_subs);
     my $results    = {
+        name              => '{code not in named subroutines}',
         lines             => $lines,
         mccabe_complexity => $complexity,
+        path              => $self->path,
     };
     return $results;
 }
@@ -217,7 +219,6 @@ sub _get_packages {
 sub _iterate_over_subs {
     my $self       = shift;
     my $found_subs = shift;
-    my $path       = shift;
 
     return []
       if ( !Perl::Metrics::Simple::Analysis::is_ref( $found_subs, 'ARRAY' ) );
@@ -228,7 +229,7 @@ sub _iterate_over_subs {
         my $sub_length = $self->get_node_length($sub);
         push @subs,
           {
-            path              => $path,
+            path              => $self->path,
             name              => $sub->name,
             lines             => $sub_length,
             mccabe_complexity => $self->measure_complexity($sub),
@@ -269,8 +270,8 @@ sub is_hash_key {
 sub _prune_comments_and_pod {
     my $document = shift;
 
-    $document->prune('PPI::Token::Comment');
-    $document->prune('PPI::Token::Pod');
+    $document->prune('PPI::Token::Comment','PPI::Token::Pod',);
+
     return $document;
 }
 
@@ -291,7 +292,7 @@ Perl::Metrics::Simple::Analysis::File - Methods analyzing a single file.
 
 =head1 VERSION
 
-This is VERSION 0.02.
+This is VERSION 0.03
 
 =head1 DESCRIPTION
 
@@ -342,6 +343,8 @@ portions of the document:
   {
     lines             => $lines,      # Line count outside subs. Skips comments and pod.
     mccabe_complexity => $complexity, # Cyclomatic complexity of all non-sub areas
+    path              => '/path/to/file',
+    name              => '{code not in named subroutines}',  # always the same name
   };
 
 =head2 get_node_length
@@ -355,11 +358,11 @@ comment lines and pod
 
 =head2 lines
 
-Total non-blank, non-comment/pod lines.
+Total non-blank, non-comment, non-pod lines.
 
 =head2 main_stats
 
-Returns the hashref generated by I<analyze_main>.
+Returns the hashref generated by I<analyze_main> without re-analyzing document.
 
 =head2 measure_complexity
 
@@ -407,7 +410,7 @@ Count of subroutines found.
 
 =head1 STATIC PACKAGE SUBROUTINES
 
-Utility subs used internally, but not harm in exposing them for now.
+Utility subs used internally, but no harm in exposing them for now.
 
 =head2 hashify
 
